@@ -11,7 +11,7 @@ my $tmpDir = $ARGV[3];
 my @cmd = qq|exercise3.pl $database $tmpDir/blast.out|;
 system(@cmd) && confess("@cmd failed: ".($?>>8));
 
-@cmd = qq|treehandler_new.pl -mfo fullTransitiveClosureGO.txt -bpo fullTransitiveClosureGO.txt -method 3 -pred $tmpDir/blast.out -scoring $scoring|;
+@cmd = qq|treehandler_new.pl -mfo fullTransitiveClosureGO.txt -bpo fullTransitiveClosureGO.txt -cco fullTransitiveClosureGO.txt -method 3 -pred $tmpDir/blast.out -scoring $scoring|;
 my $peterput=`@cmd`;
 if($?){ confess("@cmd failed: ".($?>>8)); }
 
